@@ -44,3 +44,11 @@ test_that("setup_logging existing log", {
     result <- shiny::isolate(.setup_logging(NULL,logger))
     expect_equal(class(result), c("reactiveExpr", "reactive"))
 })
+
+test_that("fw_reset_app_options", {
+    result <- periscope:::fw_reset_app_options()
+    expect_null(result, "fw_reset_app_options")
+})
+
+# clean up
+unlink("log", TRUE)
